summaryrefslogtreecommitdiff
path: root/FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h
diff options
context:
space:
mode:
Diffstat (limited to 'FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h')
-rw-r--r--FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h35
1 files changed, 16 insertions, 19 deletions
diff --git a/FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h b/FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h
index 641539ea0..8604abed0 100644
--- a/FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h
+++ b/FreeRTOS-Plus/Source/FreeRTOS-Plus-TCP/include/FreeRTOS_IP_Private.h
@@ -1,5 +1,5 @@
/*
- * FreeRTOS+TCP V2.0.11
+ * FreeRTOS+TCP V2.2.0
* Copyright (C) 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a copy of
@@ -41,10 +41,6 @@ extern "C" {
#include "FreeRTOS_TCP_IP.h"
#endif
-#if( ipconfigSOCKET_HAS_USER_SEMAPHORE == 1 )
- #include "semphr.h"
-#endif
-
#include "event_groups.h"
typedef struct xNetworkAddressingParameters
@@ -248,16 +244,17 @@ typedef enum
eNoEvent = -1,
eNetworkDownEvent, /* 0: The network interface has been lost and/or needs [re]connecting. */
eNetworkRxEvent, /* 1: The network interface has queued a received Ethernet frame. */
- eARPTimerEvent, /* 2: The ARP timer expired. */
- eStackTxEvent, /* 3: The software stack has queued a packet to transmit. */
- eDHCPEvent, /* 4: Process the DHCP state machine. */
- eTCPTimerEvent, /* 5: See if any TCP socket needs attention. */
- eTCPAcceptEvent, /* 6: Client API FreeRTOS_accept() waiting for client connections. */
- eTCPNetStat, /* 7: IP-task is asked to produce a netstat listing. */
- eSocketBindEvent, /* 8: Send a message to the IP-task to bind a socket to a port. */
- eSocketCloseEvent, /* 9: Send a message to the IP-task to close a socket. */
- eSocketSelectEvent, /*10: Send a message to the IP-task for select(). */
- eSocketSignalEvent, /*11: A socket must be signalled. */
+ eNetworkTxEvent, /* 2: Let the IP-task send a network packet. */
+ eARPTimerEvent, /* 3: The ARP timer expired. */
+ eStackTxEvent, /* 4: The software stack has queued a packet to transmit. */
+ eDHCPEvent, /* 5: Process the DHCP state machine. */
+ eTCPTimerEvent, /* 6: See if any TCP socket needs attention. */
+ eTCPAcceptEvent, /* 7: Client API FreeRTOS_accept() waiting for client connections. */
+ eTCPNetStat, /* 8: IP-task is asked to produce a netstat listing. */
+ eSocketBindEvent, /* 9: Send a message to the IP-task to bind a socket to a port. */
+ eSocketCloseEvent, /*10: Send a message to the IP-task to close a socket. */
+ eSocketSelectEvent, /*11: Send a message to the IP-task for select(). */
+ eSocketSignalEvent, /*12: A socket must be signalled. */
} eIPEvent_t;
typedef struct IP_TASK_COMMANDS
@@ -460,8 +457,8 @@ BaseType_t vNetworkSocketsInit( void );
BaseType_t xIPIsNetworkTaskReady( void );
#if( ipconfigSOCKET_HAS_USER_WAKE_CALLBACK == 1 )
- struct XSOCKET;
- typedef void (*SocketWakeupCallback_t)( struct XSOCKET * pxSocket );
+ struct xSOCKET;
+ typedef void (*SocketWakeupCallback_t)( struct xSOCKET * pxSocket );
#endif
#if( ipconfigUSE_TCP == 1 )
@@ -548,7 +545,7 @@ BaseType_t xIPIsNetworkTaskReady( void );
* This counter is separate from the xmitCount in the
* TCP win segments */
uint8_t ucTCPState; /* TCP state: see eTCP_STATE */
- struct XSOCKET *pxPeerSocket; /* for server socket: child, for child socket: parent */
+ struct xSOCKET *pxPeerSocket; /* for server socket: child, for child socket: parent */
#if( ipconfigTCP_KEEP_ALIVE == 1 )
uint8_t ucKeepRepCount;
TickType_t xLastAliveTime;
@@ -615,7 +612,7 @@ typedef enum eSOCKET_EVENT {
eSOCKET_ALL = 0x007F,
} eSocketEvent_t;
-typedef struct XSOCKET
+typedef struct xSOCKET
{
EventBits_t xEventBits;
EventGroupHandle_t xEventGroup;